Simple stack implementation.

Use:
 .push method to add a new element into stack
 .pop to delete and return last element from stack
 .peek to return a last element from stack
 .delete to delete a last element from stack
 .show to print elements from stack 
 .clear to clear a stack
 .pop_all to delete and return all elements from stack
 .peek_all to return all elements from stack
Also, this stack is iterable. The iteration starts from the last element of the stack.